'use strict';

var jsxRuntime = require('react/jsx-runtime');
var react = require('react');

function ChevronDownSvg(props) {
    return (jsxRuntime.jsx("svg", Object.assign({}, props, { width: '16', height: '16', viewBox: '0 0 16 16', fill: 'none', xmlns: 'http://www.w3.org/2000/svg' }, { children: jsxRuntime.jsx("path", { d: 'M4 6L8 10L12 6', stroke: 'currentColor', strokeWidth: '1', strokeLinecap: 'round', strokeLinejoin: 'round' }) })));
}

const JsonViewContext = react.createContext({
    collapseStringsAfterLength: 99,
    collapseObjectsAfterLength: 20
});
function JsonView({ src, collapseStringsAfterLength = 99, collapseObjectsAfterLength = 20 }) {
    return (jsxRuntime.jsx(JsonViewContext.Provider, Object.assign({ value: { collapseStringsAfterLength, collapseObjectsAfterLength } }, { children: jsxRuntime.jsx("code", Object.assign({ className: 'json-view' }, { children: jsxRuntime.jsx(JsonNode, { node: src }) })) })));
}
function JsonNode({ node }) {
    const jv = react.useContext(JsonViewContext);
    if (Array.isArray(node) || isObject(node)) {
        return jsxRuntime.jsx(ObjectNode, { node: node });
    }
    else if (typeof node === 'number')
        return jsxRuntime.jsx("span", Object.assign({ className: 'json-view--number' }, { children: node }));
    else if (typeof node === 'string')
        return node.length > jv.collapseStringsAfterLength ? (jsxRuntime.jsx(LongString, { str: node })) : (jsxRuntime.jsxs("span", Object.assign({ className: 'json-view--string' }, { children: ["\"", node, "\""] })));
    else if (typeof node === 'boolean')
        return jsxRuntime.jsx("span", Object.assign({ className: 'json-view--boolean' }, { children: String(node) }));
    else if (node === null)
        return jsxRuntime.jsx("span", Object.assign({ className: 'json-view--null' }, { children: "null" }));
    else
        return jsxRuntime.jsx("span", Object.assign({ className: 'json-view--string' }, { children: String(node) }));
}
function ObjectNode({ node }) {
    const jv = react.useContext(JsonViewContext);
    const [fold, setFold] = react.useState(Array.isArray(node) && node.length > jv.collapseObjectsAfterLength
        ? true
        : isObject(node) && Object.keys(node).length > jv.collapseObjectsAfterLength
            ? true
            : false);
    if (Array.isArray(node)) {
        return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("span", { children: '[' }), !fold && jsxRuntime.jsx(ChevronDownSvg, { onClick: () => setFold(true), className: 'jv-chevron' }), !fold ? (jsxRuntime.jsx("div", Object.assign({ className: 'jv-indent' }, { children: node.map((n, i) => (jsxRuntime.jsx(NameValue, { name: i, value: n }, i))) }))) : (jsxRuntime.jsx("button", Object.assign({ onClick: () => setFold(false), className: 'jv-button' }, { children: "..." }))), jsxRuntime.jsx("span", { children: ']' })] }));
    }
    else if (isObject(node)) {
        return (jsxRuntime.jsxs(jsxRuntime.Fragment, { children: [jsxRuntime.jsx("span", { children: '{' }), !fold && jsxRuntime.jsx(ChevronDownSvg, { onClick: () => setFold(true), className: 'jv-chevron' }), !fold ? (jsxRuntime.jsx("div", Object.assign({ className: 'jv-indent' }, { children: Object.entries(node).map(([name, value]) => (jsxRuntime.jsx(NameValue, { name: name, value: value }, name))) }))) : (jsxRuntime.jsx("button", Object.assign({ onClick: () => setFold(false), className: 'jv-button' }, { children: "..." }))), jsxRuntime.jsx("span", { children: '}' })] }));
    }
    return null;
}
function LongString({ str }) {
    if (str.length <= 10)
        return jsxRuntime.jsxs("span", Object.assign({ className: 'json-view--string' }, { children: ["\"", str, "\""] }));
    const [fold, setFold] = react.useState(true);
    return (jsxRuntime.jsxs("span", Object.assign({ onClick: () => setFold(!fold), className: 'json-view--string cursor-pointer' }, { children: ["\"", fold ? str.slice(0, 6) + '...' + str.slice(-4) : str, "\""] })));
}
function NameValue({ name, value }) {
    return (jsxRuntime.jsxs("div", { children: [jsxRuntime.jsx("span", Object.assign({ className: typeof name === 'number' ? 'json-view--index' : 'json-view--property' }, { children: name })), ":", ' ', jsxRuntime.jsx(JsonNode, { node: value })] }));
}
function isObject(node) {
    return Object.prototype.toString.call(node) === '[object Object]';
}

module.exports = JsonView;
//# sourceMappingURL=index.cjs.map
